/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VShort;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsShort;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeShort;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVShort;

/**
 * Type adapter that convert from {@link ChannelAccessControlsShort} and
 * {@link ChannelAccessTimeShort} to {@link VShort}. This adapter can only be
 * used if the value has exactly one element.
 * 
 * @author Sebastian Marsching
 */
public class ScalarShortTypeAdapter
        extends JackieDataSourceTypeAdapter<VShort> {

    /**
     * Single instance of this adapter.
     */
    public static final ScalarShortTypeAdapter INSTANCE = new ScalarShortTypeAdapter();

    private ScalarShortTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_SHORT, VShort.class);
    }

    @Override
    protected VShort convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_SHORT and we thus know that the
        // monitors return a DBR_CTRL_SHORT and DBR_TIME_SHORT.
        ChannelAccessControlsShort controlsValue = (ChannelAccessControlsShort) message
                .getControlsValue();
        ChannelAccessTimeShort timeValue = (ChannelAccessTimeShort) message
                .getTimeValue();
        return new JackieVShort(controlsValue, timeValue,
                connection.getDisconnectTime());
    }

}
