/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.vtype;

import java.time.Instant;

import org.diirt.vtype.VString;
import org.diirt.vtype.VTypeToString;

import com.aquenos.epics.jackie.common.value.ChannelAccessTimeString;

/**
 * {@link VString} implementation that is backed by a
 * {@link ChannelAccessTimeString}.
 * 
 * @see JackieVStringFromByteArray
 * @author Sebastian Marsching
 */
public final class JackieVString
        extends JackieAlarmAndTime<ChannelAccessTimeString> implements VString {

    /**
     * <p>
     * Creates a value backed by the specified {@code value}. The {@code value}
     * is used for the alarm status, time-stamp, and value. The {@code value}
     * must have exactly one element.
     * </p>
     * 
     * <p>
     * If {@code disconnectTime} is not <code>null</code>, it is used as the
     * time-stamp and the alarm severity is set to {@code UNDEFINED}.
     * </p>
     * 
     * @param value
     *            value used for alarm status, time-stamp, and value. It must
     *            have exactly one element.
     * @param disconnectTime
     *            time at which the channel was disconnected. Usually this
     *            should be <code>null</code>. If it is not <code>null</code>,
     *            the alarm severity is set to {@code UNDEFINED} and this
     *            parameter is used as the time-stamp (instead of using the
     *            time-stamp from the {@code timeValue}.
     * @throws IllegalArgumentException
     *             if {@code value} has more or less than one element.
     */
    public JackieVString(ChannelAccessTimeString value,
            Instant disconnectTime) {
        super(value, disconnectTime, true);
    }

    @Override
    public String getValue() {
        return timeValue.getValue().get(0);
    }

    @Override
    public String toString() {
        return VTypeToString.toString(this);
    }

}
